/* RF ---------------------------------------------------------------------
Arquivo   : sb_actel.c

Descr	  : Functions concerning the service board actel.
--------------------------------------------------------------------------- */
/*--------------------------------------------------------------------------- */
#include "stdafx.h"
#include "Commctrl.h"
#include <windows.h>
#include <iostream>
#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include "canopen_custom.h"
#include "ccan.h"
#include "elmb.h"
#include "canopen.h"

#include "resource.h"
#include "math.h"
#include "i2c_functions.h"
#include "sb_actel.h"

extern CAN_INTERFACE_TYPE CanInterface;

using namespace std;


Sb_Actel::Sb_Actel() //constructor
{
	//initialize variables	
	index_actel = 0x4700;
	data[0] = 0;
	data[1] = 0;
	data[2] = 0;
	data[3] = 0;
}
Sb_Actel::~Sb_Actel() //destructor
{
}


bool Sb_Actel::send_40M_clk(int node_id)
{
	data[0]=CLK40;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TEST_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;					

	return TRUE;

}

bool Sb_Actel::send_long_pulse(int node_id)
{
	data[0]=REG_PULSE;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TEST_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;
		//											 i2c0_addr0x9E			output enalble					
	data[0]=0x0;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf)) return FALSE;

	data[0]=0x1;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf)) return FALSE;

	data[0]=0x0;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf)) return FALSE;

	return TRUE;
}

bool Sb_Actel::send_1000long_pulse(int node_id)
{
	int i;

	data[0]=SW_PULSE;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_INT_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;

	data[0]=REG_PULSE;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TEST_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;
		//											 i2c0_addr0x9E			output enalble					
	data[0]=0x0;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf)) return FALSE;

	for(i=0; i<=99;i++)
	{		
		data[0]=0x1;
		if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf));
		data[0]=0x0;
		if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf));
	}
	
	return TRUE;
}

bool Sb_Actel::select_swpulse_mode(int node_id)
{
	data[0]=SW_PULSE;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_INT_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;
	data[0]=INT_PULSE;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TEST_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;

	return TRUE;
}

bool Sb_Actel::select_sw_start_stop_mode(int node_id)
{
	data[0]=SW_START_STOP;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_INT_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;
	data[0]=INT_PULSE;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TEST_PULSE_SEL, 1, data,can_msg_cnf)) return FALSE;

	return TRUE;
}

bool Sb_Actel::set_tmis_time_ms(int node_id, int time) //write all TMIS registers according to time
{
	unsigned int TMIS;

	TMIS = ((time*1000000)/25)-1;
	data[0]=TMIS & 0xff;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TMIS_L, 1, data,can_msg_cnf)) return FALSE;
	data[0]=(TMIS >> 8 ) & 0xff;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_TMIS_H, 1, data,can_msg_cnf)) return FALSE;
	data[0]=(TMIS >> 16 ) & 0xff;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_ACTEL_PRESCAL_L, 1, data,can_msg_cnf)) return FALSE;
	data[0]=(TMIS >> 24 ) & 0xff;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_ACTEL_PRESCAL_H, 1, data,can_msg_cnf)) return FALSE;

	return TRUE;
}

bool Sb_Actel::write_ADDR_PULSE(int node_id) //write to this register
{
	data[0]=0x1;
	if(!COP_WriteSDO (CanInterface, node_id, 1, index_actel, ADDR_PULSE, 1, data,can_msg_cnf)) return FALSE;

	return TRUE;
}
